"""Drinks API."""

import json

from flask import Blueprint, Response, current_app, request
from sqlalchemy import select
from sqlalchemy.orm import Session

from mxr.orm import Drinks

drinks = Blueprint("drinks", __name__, template_folder="templates")


@drinks.route("/drinks", methods=["POST"])
def create_drink() -> Response:
    """Create a drink."""
    drink_data = request.get_json()

    with Session(current_app.config["ENGINE"]) as session:
        drink = Drinks(
            name=drink_data["name"],
            garnish=drink_data.get("garnish"),
            ingredients=drink_data["ingredients"],
            preparation=drink_data["preparation"],
        )
        session.add(drink)
        session.commit()
        id = drink.id

    return Response(status=201, response=json.dumps({"id": id}))


@drinks.route("/drinks")
def get_drinks() -> Response:
    """Get the drinks."""
    with Session(current_app.config["ENGINE"]) as session:
        raw_drinks = session.execute(select(Drinks)).scalars().all()

    drinks_data = json.dumps(
        [
            {
                "id": drink.id,
                "name": drink.name,
                "garnish": drink.garnish,
                "ingredients": drink.ingredients,
                "preparation": drink.preparation,
            }
            for drink in raw_drinks
        ]
    )

    return Response(status=201, response=drinks_data)


@drinks.route("/drinks/<int:id>")
def get_drink(id: int) -> Response:
    """Get a drink."""
    with Session(current_app.config["ENGINE"]) as session:
        drink = session.execute(select(Drinks).where(Drinks.id == id)).scalars().one()

    return Response(
        status=201,
        response=json.dumps(
            {
                "id": drink.id,
                "name": drink.name,
                "garnish": drink.garnish,
                "ingredients": drink.ingredients,
                "preparation": drink.preparation,
            }
        ),
    )


@drinks.route("/drinks/<int:id>", methods=["PUT"])
def update_drink(id: int) -> Response:
    """Update a drink."""
    drink_data = request.get_json()
    with Session(current_app.config["ENGINE"]) as session:
        drink = session.execute(select(Drinks).where(Drinks.id == id)).scalars().one()
        drink.name = drink_data.get("name", drink.name)
        drink.garnish = drink_data.get("garnish", drink.garnish)
        drink.ingredients = drink_data.get("ingredients", drink.ingredients)
        drink.preparation = drink_data.get("preparation", drink.preparation)
        session.commit()

    return Response(status=200)
